@@ -30,21 +30,17 @@ sub transform {
         my $count = $address_stop->{middle}{$_} || '';
         (length $count and @tokens >= $count) ? () : $_;
     } @tokens;
-    @filtered = @tokens;
 
     # revert if we filtered words down to less than 2 tokens
     @filtered = @tokens if @filtered < 2;
 
-    $value = join ' ', @tokens;
-
-
-    return $value;
+    return join ' ', @filtered;
 }
 
 sub new {
     my $self = shift;
-    $address_stem = String::Normal::Config::AddressStem::_data();
-    $address_stop = String::Normal::Config::AddressStop::_data();
+    $address_stem = String::Normal::Config::AddressStem::_data( @_ );
+    $address_stop = String::Normal::Config::AddressStop::_data( @_ );
     return bless {@_}, $self;
 }
 
