@@ -44,16 +44,16 @@ sub transform {
     # If we filtered all words out, "revert" to the full array of stemmed tokens.
     @filtered = @words unless @filtered;
 
-    # The canon biz is the sorted filtered stemmed words plus the original digits.
+    # The canon name is the sorted filtered stemmed words plus the original digits.
     return join ' ', sort @digits, @filtered;
 }
 
 sub new {
     my $self = shift;
     $STEM = Lingua::Stem->new;
-    $STEM->add_exceptions( String::Normal::Config::BusinessStem::_data );  #TODO: override default files
-    $biz_stop     = String::Normal::Config::BusinessStop::_data;
-    $biz_compress = String::Normal::Config::BusinessCompress::_data;
+    $STEM->add_exceptions( String::Normal::Config::BusinessStem::_data( @_ ) );  #TODO: override default files
+    $biz_stop     = String::Normal::Config::BusinessStop::_data( @_ );
+    $biz_compress = String::Normal::Config::BusinessCompress::_data( @_ );
     return bless {@_}, $self;
 }
 
