@@ -9,7 +9,7 @@ our $codes;
 sub transform {
     my ($self,$value) = @_;
 
-    # Replace phone letters with numbers and remove non-digits
+    # Replace phone letters with numbers and remove non-digits (credit Ray Toal)
     $value =~ tr/a-z/22233344455566677778889999/;
     $value =~ s/\D//g;
 
@@ -31,7 +31,7 @@ sub transform {
 
 sub new {
     my $self = shift;
-    $codes = String::Normal::Config::AreaCodes::_data();
+    $codes = String::Normal::Config::AreaCodes::_data( @_ );
     return bless {@_}, $self;
 }
 
